#!/ysr/bin/env python
#-*- coding:utf-8 -*-
__author__ = "yua"

from .AWSClient import AWSClient

class ELBClient(AWSClient):
    def __init__(self, aws_access_key_id="", aws_secret_access_key="", region="", elb_name=""):
        super().__init__(aws_access_key_id, aws_secret_access_key, region)
        self.client = super().get_session().client('elbv2')
        self.elb_name = elb_name

    def describe_elb(self):
        """
        查询elb详细信息
        :return: json
        """
        return self.client.describe_load_balancers(Names=[self.elb_name,])['LoadBalancers'][0]

    def get_elb_arn(self):
        """
        返回elb的 arn字段
        :return: string
        """
        return self.describe_elb()['LoadBalancerArn']

    def get_listeners(self):
        """
        获取elb的监听器
        :return: list
        """
        return self.client.describe_listeners(LoadBalancerArn=self.get_elb_arn())['Listeners']

    def get_target_groups_arn(self):
        """
        获取elb监听器的实例组 去重复
        :return: list
        """
        list_target_groups_arn = []
        for listener in self.get_listeners():
            for target_group in listener['DefaultActions']:
                list_target_groups_arn.append(target_group['TargetGroupArn'])

        return list(set(list_target_groups_arn))

    def get_target_groups_instance(self):
        """
        获取elb中实例组中的实例 未去重复
        :return: list
        """
        list_instances = []
        for target_group_arn in self.get_target_groups_arn():
            for instance in self.client.describe_target_health(TargetGroupArn=target_group_arn)['TargetHealthDescriptions']:
                list_instances.append(instance)

        return list_instances

    def get_target_groups_instance_id(self):
        """
        获取elb中实例组中的实例id 未去重复(get_target_groups_instance 未去重复)
        :return: list
        """
        list_instances_id = []
        for instance in self.get_target_groups_instance():
            list_instances_id.append(instance['Target']['Id'])

        return list(set(list_instances_id))
