#!/ysr/bin/env python
#-*- coding:utf-8 -*-
__author__ = "yua"

import boto3
from .AWSClient import AWSClient

class S3Client(AWSClient):
    def __init__(self, aws_access_key_id="", aws_secret_access_key="", region="", bucket_name=""):
        super().__init__(aws_access_key_id, aws_secret_access_key, region)
        self.client = super().get_session().client('s3')
        self.bucket_name = bucket_name

    def search_s3_files(self, Prefix=''):
        """
        搜索prefix目录下的所有文件/文件夹
        返回json
        :param Prefix: string (data/service)
        :return: json
        """
        try:
            response = self.client.list_objects_v2(Bucket=self.bucket_name, Prefix=Prefix)
            return response['Contents']
        except Exception as e:
            print(str(e))
            return False

    def upload_file(self, local_path, remote_path):
        """
        上传单个文件到s3
        :param local_path: string (/data/test.txt)
        :param remote_path: string (data/service/test.txt)
        :return: boolean
        """
        try:
            # self.s3.meta.client.upload_file(local_path, self.bucket_name, remote_path)
            self.client.upload_file(local_path, self.bucket_name, remote_path)
            return True
        except Exception as e:
            print(str(e))
            return False

    def download_file(self, remote_path, local_path):
        """
        下载单个文件到本地
        :param remote_path: string (data/service/test.txt)
        :param local_path: string (/data/test.txt)
        :return: boolean
        """
        try:
            self.client.download_file(self.bucket_name, remote_path, local_path)
            return True
        except Exception as e:
            print(str(e))
            return False

    def set_tagging(self, key, set_tag_list):
        """
        设置某个资源的标签
        key s3文件路径
        set_tag_list 为数组,可设置多个标签
        :param key: string (data/service/test.txt)
        :param set_tag_list: list ( [{'Key': 'release', 'Value': 'true'}] )
        :return: boolean
        """
        try:
            self.client.put_object_tagging(Bucket=self.bucket_name, Key=key, Tagging={'TagSet': set_tag_list})
            return True
        except Exception as e:
            print(str(e))
            return False

    def get_tagging(self, key):
        """
        获取某个资源的所有标签 返回数组
        :param key: string (data/service/test.txt)
        :return: list ([{'xx':'xx','xxx':'xxx'}])
        """
        try:
            response = self.client.get_object_tagging(Bucket=self.bucket_name, Key=key)
            return response['TagSet']
        except Exception as e:
            print(str(e))
            return False