#!/ysr/bin/env python
#-*- coding:utf-8 -*-
__author__ = "yua"

import os, hashlib, zipfile, requests

class FileManage(object):
    def __init__(self, file_path):
        self.file_path = file_path

    def file_append(self, text):
        """
        在文件中 追加文本
        :param text: string
        :return: boolean
        """
        try:
            file_obj = open(self.file_path, 'a')
            file_obj.write(text)
            file_obj.flush()
            file_obj.close()
            return True
        except Exception as e:
            print(str(e))
            return False

    def search_text_in_file(self, text):
        """
        查找文本是否在文件中
        :param text: string
        :return: boolean
        """
        try:
            file_obj = open(self.file_path, 'r')
            if file_obj.read().find(text) != -1:
                file_obj.close()
                return True
            else:
                file_obj.close()
                return False
        except Exception as e:
            print(str(e))
            return False

    def file_write_bin(self, bin_text):
        """
        覆盖写入文件
        :param bin_text: binary
        :return: boolean
        """
        try:
            file_obj = open(self.file_path, 'wb')
            file_obj.write(bin_text)
            file_obj.flush()
            file_obj.close()
            return True
        except Exception as e:
            print(str(e))
            return False

class FileMD5Check(object):
    def __init__(self, file_path):
        self.file_path = file_path

    def make_md5(self):
        """
        生成文件 md5码
        :return: string
        """
        packet_file_obj = open(self.file_path, 'rb')
        contents = packet_file_obj.read()
        packet_file_obj.close()
        file_md5 = hashlib.md5(contents).hexdigest()

        return file_md5

    def check_files_md5(self, md5_file_path):
        """
        检查文件中的md5码 是否等于文件的md5码
        :param md5_file_path: string
        :return:  boolean
        """
        if os.path.isfile(self.file_path):
            file_md5 = self.make_md5()

            md5_file_obj = open(md5_file_path, 'r')
            md5_number = md5_file_obj.read().replace('\n', '').replace(' ', '')

            if file_md5 == md5_number:
                return True
            else:
                return False
        else:
            return False

    def check_files_md5_str(self, md5_str):
        # 传参md5文件
        """
        检查 md5字符串 是否等于文件md5码
        :param md5_str: string
        :return: boolean
        """
        if os.path.isfile(self.file_path):
            file_md5 = self.make_md5()
            if file_md5 == md5_str:
                return True
            else:
                return False
        else:
            return False

class FileZip(object):
    def __init__(self, file_path, file_base_dir='', file_mode='r'):
        self.file_path = file_path
        self.file_base_dir = file_base_dir
        self.file_mode = file_mode

    def unzip_file(self):
        """
        加压文件
        :return: boolean
        """
        if os.path.isfile(self.file_path):
            zip_file_obj = zipfile.ZipFile(self.file_path, self.file_mode)
            try:
                for file_name in zip_file_obj.namelist():
                    zip_file_obj.extract(file_name, os.path.dirname(self.file_path))
                return True
            except Exception as e:
                print(e)
        else:
            return False

class GetHttpFile(object):
    def __init__(self, http_url):
        """
        http_url 远端服务器地址
        :param http_url: string
        """
        self.http_url = http_url

    def http_get_file(self, data_dir, authenticate_key,dict_file):
        """
        获取远程服务器上的文件
        data_dir 本地存放文件目录
        authenticate_key 远程服务器的认证key
        dict_file 文件信息  {'project':'iap_service', 'file_name':'iap_service_1234', 'version':1234} 项目名，文件名，版本
        返回 本地文件路径
        :param data_dir: string
        :param authenticate_key: string
        :param dict_file: json
        :return: string
        """
        obj_response = requests.get(self.http_url, params={'agent_key': authenticate_key, 'file_info': str(dict_file)})
        print(obj_response.content)
        dict_response = eval(obj_response.content)

        if obj_response.status_code == 200:
            obj_file = FileManage(os.path.join(data_dir, dict_file['file_name']))
            obj_file.file_write_bin(dict_response['file_bin'])

            obj_md5 = FileMD5Check(os.path.join(data_dir, dict_file['file_name']))
            if obj_md5.check_files_md5_str(dict_response['file_md5']):
                return os.path.join(data_dir, dict_file['file_name'])
            else:
                return False
        else:
            return False
