#!/ysr/bin/env python
#-*- coding:utf-8 -*-
__author__ = "yua"

import smtplib, os
from email.header import Header
from email.mime.text import MIMEText
from email.utils import formataddr
from email.mime.multipart import MIMEMultipart
from email.mime.application import MIMEApplication

class SystemEmail(object):
    def __init__(self, dict_send_msg, email_addr, email_alias):
        """
        dict_send_msg发件人信息
            send_email_addr发件人地址
            send_email_alias发件人别名
            send_email_key发件人key
            smtp_server发件人服务器
        email_addr 收件人地址
        email_alias 收件人别名
        :param dict_send_msg:
        :param email_addr:
        :param email_alias:
        """
        self.email_addr = email_addr
        self.email_alias = email_alias
        self.dict_send_msg= dict_send_msg

        self.send_email_addr = dict_send_msg['send_email_addr']
        self.send_email_alias = dict_send_msg['send_email_alias']
        self.send_email_key = dict_send_msg['send_email_key']

    def __get_format_addr(self, name, addr):
        """
        装载 用户信息
        name 邮件别名
        addr 邮件地址
        :param name: string
        :param addr: string
        :return: format object
        """
        return formataddr((Header(name, 'utf-8').encode(), addr))

    def __get_send_email_server(self):
        """
        装载 邮件服务器信息
        :return: email server object
        """
        obj_server = smtplib.SMTP_SSL(self.dict_send_msg['smtp_server'], 465)
        obj_server.login(self.send_email_addr, self.send_email_key)

        return obj_server

    def send_email(self, subject, body, attachment=None):
        """
        发送邮件
        subject 邮件主题
        body 邮件内容
        attachment 附件路径信息 列表 多个附件多个文件路径
        :param subject: string
        :param body: string
        :param attachment: list
        :return: boolean
        """
        try:
            obj_mime = MIMEMultipart()
            obj_mime['From'] = self.__get_format_addr(self.send_email_alias, self.send_email_addr)
            obj_mime['To'] = self.__get_format_addr(self.email_alias, self.email_addr)
            obj_mime['Subject'] = Header(subject, 'utf-8').encode()

            obj_body = MIMEText(body, 'plain', 'utf-8')
            obj_mime.attach(obj_body)
            if attachment:
                for i in attachment:
                    obj_part = MIMEApplication(open(i, 'rb').read())
                    obj_part.add_header('Content-Disposition', 'attachment', filename=os.path.basename(i))
                    obj_mime.attach(obj_part)

            obj_server = self.__get_send_email_server()
            obj_server.sendmail(self.send_email_addr, [self.email_addr], obj_mime.as_bytes())
            obj_server.quit()
            return True
        except Exception as e:
            print(str(e))
            return False


